xrayutilities.simpack package
=============================

Submodules
----------

xrayutilities.simpack.darwin\_theory module
-------------------------------------------

.. automodule:: xrayutilities.simpack.darwin_theory
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.simpack.fit module
--------------------------------

.. automodule:: xrayutilities.simpack.fit
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.simpack.helpers module
------------------------------------

.. automodule:: xrayutilities.simpack.helpers
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.simpack.models module
-----------------------------------

.. automodule:: xrayutilities.simpack.models
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.simpack.powder module
-----------------------------------

.. automodule:: xrayutilities.simpack.powder
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.simpack.powdermodel module
----------------------------------------

.. automodule:: xrayutilities.simpack.powdermodel
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.simpack.smaterials module
---------------------------------------

.. automodule:: xrayutilities.simpack.smaterials
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: xrayutilities.simpack
    :members:
    :undoc-members:
    :show-inheritance:
